@@ -1,6 +1,7 @@
 import numpy as np
 import pandas as pd
 from sklearn.linear_model import LinearRegression
+import warnings
 
 
 class Model:
@@ -9,7 +10,7 @@ class Model:
         models on."""
 
     def __init__(self, df=None, dependent_col="load", temperature_col="temp",
-                 dependent_df=None, temperature_df=None, occupancy_col=None, 
+                 dependent_df=None, temperature_df=None, occupancy_col=None,
                  additional_vars_df=None, model_name="TOWT"):
         """
         Initialize object by ensuring dataframe is fit for modeling and noting
@@ -48,7 +49,7 @@ class Model:
             ChangePoint options are: SLR, 3PC, 3PH, 4P, 5P
             HDD_CDD options are: HD, CD, HD-CD
             default is towt.
-            
+
         Raises
         ------
         KeyError
@@ -67,10 +68,10 @@ class Model:
         self.interval_tiers = {'Monthly': 1, 'Daily': 2,
                                'Hourly': 3, '15 Minute': 4}
         self.model_interval = None
-            
+
         if df is not None:
             if isinstance(df, pd.DataFrame):
-                self.df = df
+                self.df = df.copy()  # copy to not overwrite original df obj
                 self.timestamp_col = self.__check_timestamp_col(df)
                 self.min_interval = self.infer_interval(self.df,
                                                         self.timestamp_col)
@@ -84,18 +85,21 @@ class Model:
                 # x_train_cols does not include temp column because it can make
                 # a variable number of extra columns depending on modeling algo
                 self.x_train_cols = list(self.df.drop(
-                    columns=[x for x in not_x_cols if x is not None], axis=1).columns)
+                    columns=[x for x in not_x_cols if x is not None]).columns)
                 try:
                     self.df[[dependent_col]]
                 except KeyError:
                     raise KeyError(
-                        "Supplied dependent variable column name is but it was not found in the supplied"
+                        "Supplied dependent variable column name is " +
+                        dependent_col + " but it was not found in the supplied"
                         " dataframe.")
             else:
                 raise ValueError("Supplied dataset is not a pandas dataframe.")
             if dependent_df is not None:
-                raise ValueError("Supplied dataset is not a pandas dataframe.")
-
+                warnings.warn("df argument is assuming the full regression "
+                              "dataset with the dependent variable and other "
+                              "regressors. Another value was passed as the "
+                              "dependent dataframe. Ignoring it.")
 
         elif dependent_df is not None:
             if isinstance(dependent_df, pd.DataFrame):
@@ -131,11 +135,18 @@ class Model:
             self.group_method = dict(
                 zip([self.dependent_col, self.temperature_col,
                      self.occupancy_col] + self.x_train_cols,
-                    ["sum", "mean", "mean"] + ["sum" for x in
-                                               range(len(self.x_train_cols))]))
+                    ["sum", "mean", "max"] + ["sum" for x in
+                                              range(len(self.x_train_cols))]))
             self.group_method.pop(None, None)
             
-
+            # Get number of non-dependent columns
+            self.train_col_list = self.x_train_cols.copy()
+            self.train_col_list += [self.temperature_col]
+            self.train_col_list += [self.occupancy_col] if self.occupancy_col is not None else []
+        else:
+            self.train_col_list = [self.temperature_col]
+            self.train_col_list += [self.occupancy_col] if self.occupancy_col is not None else []
+            
 
     def aggregate(self, dependent_df=None, temperature_df=None,
                   additional_vars_df=None):
@@ -159,8 +170,6 @@ class Model:
         None.
         """
 
-
-
         max_time_col = self.__check_timestamp_col(dependent_df)
         min_interval = self.infer_interval(dependent_df,
                                            max_time_col)
@@ -239,7 +248,7 @@ class Model:
         pass
 
     def find_occ_unocc(self, hd_base=50, cd_base=65, time_interval="Monthly",
-                       occ_threshold=0.65):
+                       occ_threshold=0.65, inplace=True):
         """
         Determine occupancy schedule based off usage.
         Parameters
@@ -297,7 +306,24 @@ class Model:
         out = orig_copy.merge(
             df_regress[[self.timestamp_col, 'occ']], on=self.timestamp_col,
             how='outer').sort_values(by=self.timestamp_col)
-
+        if inplace:
+            self.df = out
+        else:
+            self.df = orig_copy
+            
+        # Summarize occupancy schedule
+        occ_sched = pd.DataFrame()
+        if time_interval.upper()=="DAILY":
+            tow = out[self.timestamp_col].dt.dayofweek
+        elif time_interval.upper()=="HOURLY":
+            dow = out[self.timestamp_col].dt.dayofweek
+            hour = out[self.timestamp_col].dt.hour
+            tow = dow*24+hour
+        occ_sched['tow'] = tow
+        occ_sched['occ'] = out['occ']
+        occ_sched = occ_sched.groupby('tow').mean().to_dict()['occ']
+        self.determined_occ_sched = occ_sched
+        
         return(out)
 
     def format_results(self, prediction_df):
@@ -414,10 +440,8 @@ class Model:
         return(main)
 
 
-'''
-    @staticmethod
-    def r2(df):
-        rss = ((df['load'] - df['predict']) ** 2).sum()
+    def r2(self, df):
+        rss = ((df['load'] - df['y_fit']) ** 2).sum()
         y_bar = df['load'].mean()
         tss = ((df['load'] - y_bar) ** 2).sum()
         r2 = 1 - (rss / tss)
@@ -426,33 +450,33 @@ class Model:
 
     def adj_r2(self, df):
         r_squared = self.r2(df)
-        rt = ((1 - r_squared) * (self.records - 1)) / \
-            (self.records - self.predicted_columns - 1)  # right term
+        rt = ((1 - r_squared) * (len(df) - 1)) / \
+            (len(df) - len(self.train_col_list) - 1)  # right term
         adj_r_squared = 1 - rt
 
         return np.round(adj_r_squared, 4)
 
-    def cvrmse(self, df) -> np:
+    def cvrmse(self, df):
         """
         Coefficient of Variation of the Root Mean Square Error (Percentage)
         :param df:  pandas dataframe consisting of the data the model was built
                     off of with the predicted values
         """
-        rmse = (((df['load'] - df['predict']) ** 2).sum() /
-                (self.records - self.predicted_columns)) ** (1 / 2)
+        rmse = (((df['load'] - df['y_fit']) ** 2).sum() /
+                (len(df) - len(self.train_col_list))) ** (1 / 2)
         cvrmse = rmse / df['load'].mean()
 
         return np.round(cvrmse, 4)
 
-    @staticmethod
-    def nmbe(df):
-        nmbe = (df['load'] - df['predict']).sum() / df['load'].sum()
+    def nmbe(self, df):
+        nmbe = (df['load'] - df['y_fit']).sum() / df['load'].sum()
 
         return np.round(nmbe, 4)
 
     def metrics(self, df):
+        
         return {'R2': self.r2(df),
                 'adj R2': self.adj_r2(df),
                 'CVRMSE': self.cvrmse(df),
                 'NMBE': self.nmbe(df)}
-'''
+
