@@ -1,4 +1,4 @@
-from .Model import Model
+from Model import Model
 import pandas as pd
 from sklearn.linear_model import LinearRegression
 
@@ -12,14 +12,17 @@ class HDDCDDModel(Model):
         """
         The class assumes a dataframe with HD and CD values that are already
         calculated.
+
         Parameters
         ----------
         df : Pandas DataFrame, optional
             If training a model, a dataframe must be provided. If using only
             for predictions, a dataframe is not needed when initialized.
+
         Returns
         -------
         None.
+
         """
         super().__init__(df=df,
                          dependent_col=dependent_col,
@@ -44,6 +47,7 @@ class HDDCDDModel(Model):
     def train(self, model="HD-CD", interval=None):
         """
         Model training method for heating degree and cooling degree models.
+
         Parameters
         ----------
         model : str, optional
@@ -54,10 +58,12 @@ class HDDCDDModel(Model):
             String value to specify which interval the model should be ran at.
             If no value is given, it will default to the minimum possible
             interval.
+
         Returns
         -------
         out : Pandas DataFrame
             Modeled dataframe with predicted values.
+
         """
 
         # Checks
@@ -78,15 +84,15 @@ class HDDCDDModel(Model):
                 self.min_interval + '.')
 
         if model == "HD-CD":
-            self.temp_train_cols = ['hd', 'cd']
+            self.temp_train_cols = ['HD', 'CD']
             self.x_train_cols = list(
                 set(self.x_train_cols + self.temp_train_cols))
         elif model == "HD":
-            self.temp_train_cols = ['hd']
+            self.temp_train_cols = ['HD']
             self.x_train_cols = list(
                 set(self.x_train_cols + self.temp_train_cols))
         elif model == "CD":
-            self.temp_train_cols = ['cd']
+            self.temp_train_cols = ['CD']
             self.x_train_cols = list(
                 set(self.x_train_cols + self.temp_train_cols))
         else:
@@ -114,6 +120,7 @@ class HDDCDDModel(Model):
     def predict(self, df, timestamp_col='time'):
         """
         Predict method for heating degree and cooling degree methods.
+
         Parameters
         ----------
         df : Pandas DataFrame
@@ -126,9 +133,11 @@ class HDDCDDModel(Model):
             If None, will assume it is an object attribute. If object attribute
             is also None, will assume there is no unoccupied model to predict
             on.
+
         Returns
         -------
         Predictions attached to main dataframe.
+
         """
 
         # Checks
@@ -152,4 +161,4 @@ class HDDCDDModel(Model):
         pred['predict'] = self.model.predict(x_pred)
         out = pred[[temp_time_col, 'predict']].merge(
             main, on=temp_time_col, how='outer')
-        return(out)
\ No newline at end of file
+        return(out)
