@@ -1,4 +1,4 @@
-from .Model import Model
+from Model import Model
 import pandas as pd
 import numpy as np
 from sklearn.linear_model import LinearRegression
@@ -9,7 +9,8 @@ class TOWTModel(Model):
     def __init__(self, df=None, dependent_col="load", temperature_col="temp",
                  occupancy_col=None, dependent_df=None, temperature_df=None,
                  additional_vars_df=None, occ_threshold=0.65,
-                 knot_temps=[40, 55, 65, 80, 90], model_name="TOWT"):
+                 knot_temps=[40, 55, 65, 80, 90], define_knot_temps=True,
+                 model_name="TOWT"):
         """
         Initialize object by ensuring data provided is fit for modeling and
         noting model specs.
@@ -57,6 +58,7 @@ class TOWTModel(Model):
             Specific model name.
             Options are: TOW, TOWT
             Upper or lower case is accepted. Default is TOWT.
+
         Returns
         -------
         None.
@@ -71,11 +73,17 @@ class TOWTModel(Model):
                          model_name=model_name)
         self.temp_train_cols = []
         self.tow_train_cols = []
-        self.knot_temps = knot_temps
         self.occ_threshold = occ_threshold
+        self.determined_occ_sched = None
+        if self.df is not None:
+            self.df = self.df.groupby(self.timestamp_col).mean().reset_index()
 
+        if define_knot_temps:
+            self.knot_temps = self.define_kts()
+        else:
+            self.knot_temps = knot_temps
         if self.model_name not in ["TOWT", "TOW"]:
-            raise ValueError("Unknonwn model type: " + self.model_name + ". "
+            raise ValueError("Unknown model type: " + self.model_name + ". "
                              "Please specify model_name as TOW or TOWT.")
 
     def train(self, interval=None, knot_temps=None):
@@ -112,6 +120,7 @@ class TOWTModel(Model):
         if min_available_interval_num > desired_interval_num:
             self.df = self.group_interval(time_interval=interval,
                                           time_col=self.timestamp_col)
+        self.df.reset_index(drop = True, inplace = True)
 
         if min_available_interval_num < desired_interval_num:
             raise ValueError(
@@ -144,20 +153,24 @@ class TOWTModel(Model):
 
         # Assemble regression datasets
         if self.occupancy_col is None:
-            self.df = self.find_occ_unocc(time_interval=self.model_interval)
+            self.df = self.find_occ_unocc(
+                time_interval=self.model_interval,
+                occ_threshold=self.occ_threshold)
             self.occupancy_col = 'occ'
-
+            self.df.reset_index(drop = True, inplace = True)
+            if self.df[self.occupancy_col].nunique() == 1:
+                self.df[self.occupancy_col] = 1
+            #occ_sched = self.df[[self.timestamp_col, self.occupancy_col]]
         main = pd.concat([self.df, temp_vars, tow_vars], axis=1)
         train = main.dropna().copy()
-
         # Create models and predict
         # Occupied model
         occ_x_train = train.loc[train[self.occupancy_col]
-                                == 1, self.x_train_cols]
+                                == 1, self.x_train_cols].copy()
         occ_y_train = train.loc[train[self.occupancy_col]
-                                == 1, self.dependent_col]
+                                == 1, self.dependent_col].copy()
         occ_check = occ_x_train.loc[:, tow_vars.columns].sum() != 0
-        occ_x_train[occ_check.index[occ_check].tolist()[-1]] = 0
+        occ_x_train[occ_check.index[occ_check].tolist()[0]] = 0
         zero_check = occ_x_train.loc[:, tow_vars.columns].sum() == 0
         occ_x_train.drop(columns=zero_check.index[zero_check].tolist(),
                          inplace=True)
@@ -167,41 +180,17 @@ class TOWTModel(Model):
         # Unoccupied model
         if train[self.occupancy_col].nunique() > 1:
             unocc_x_train = train.loc[train[self.occupancy_col]
-                                      == 0, self.x_train_cols]
+                                      == 0, self.x_train_cols].copy()
             unocc_y_train = train.loc[train[self.occupancy_col]
-                                      == 0, self.dependent_col]
+                                      == 0, self.dependent_col].copy()
             unocc_check = unocc_x_train.loc[:, tow_vars.columns].sum() != 0
-            unocc_x_train[unocc_check.index[unocc_check].tolist()[-1]] = 0
+            unocc_x_train[unocc_check.index[unocc_check].tolist()[0]] = 0
             zero_check = unocc_x_train.loc[:, tow_vars.columns].sum() == 0
             unocc_x_train.drop(columns=zero_check.index[zero_check].tolist(),
                                inplace=True)
             unocc_model = LinearRegression().fit(unocc_x_train, unocc_y_train)
             self.unocc_model = unocc_model
 
-        '''
-        occ_model, occ_train = model_and_predict(train=train, occupied=True)
-        # Unoccupied model
-        unocc_model = None
-        unocc_train = pd.DataFrame()
-        if train['occ'].nunique() > 1:
-            unocc_model, unocc_train = model_and_predict(
-                train=train, occupied=False)
-        # Merge dataset back together
-        train_estimate = pd.concat([occ_train, unocc_train])
-        train_estimate = pd.concat([main, train_estimate['predict']], axis=1)
-        # Get metrics
-        metrics = {'R2': R2(train_estimate),
-                   'adj R2': adjR2(train_estimate),
-                   'CVRMSE': cvrmse(train_estimate),
-                   'NMBE': nmbe(train_estimate)}
-        # Create dictionary for model/function outputs
-        output = {"occupied model": occ_model,
-                  "unoccupied model": unocc_model,
-                  "data": train_estimate,
-                  'knot_temps': (knot_temps, used_knot_temps),
-                  'metrics': metrics}
-        return(output)
-        '''
         return(main)
 
     def predict(self, df):
@@ -212,6 +201,7 @@ class TOWTModel(Model):
         df : Pandas DataFrame
             Dataframe consisting of at least time['time'] and occupancy['occ'].
             Temp is needed for TOWT.
+
         Returns
         -------
         The main pandas dataframe with the predictions attached to it.
@@ -233,21 +223,35 @@ class TOWTModel(Model):
 
         main = pd.concat([df, temp_vars, tow_vars], axis=1)
         pred = main.dropna().copy()
+        # Fill in occ sched based off trained model if occ not supplied
+        if self.determined_occ_sched is not None:
+            if self.model_interval.upper()=="DAILY":
+                tow = pred[self.timestamp_col].dt.dayofweek
+                pred[self.occupancy_col] = tow.replace(self.determined_occ_sched)
+            elif self.model_interval.upper()=="HOURLY":
+                dow = pred[self.timestamp_col].dt.dayofweek
+                hour = pred[self.timestamp_col].dt.hour
+                tow = dow*24+hour
+                pred[self.occupancy_col] = tow.replace(self.determined_occ_sched)
+            if pred[self.occupancy_col].nunique() == 1:
+                pred[self.occupancy_col] = 1
+                
         if self.model_name == "TOWT":
             pred.drop(columns=['time', 'temp'], inplace=True)
         else:
             pred.drop(columns=['time'], inplace=True)
-
+        
+        
         # Predict
         occ_x_pred = pd.DataFrame()
         unocc_x_pred = pd.DataFrame()
-        if 1 in df[self.occupancy_col].unique():
+        if 1 in pred[self.occupancy_col].unique():
             occ_x_pred = pred.loc[pred[self.occupancy_col] == 1,
                                   pred.columns != self.dependent_col]
             occ_x_pred.drop(columns=self.occupancy_col, inplace=True)
             occ_x_pred = occ_x_pred.loc[:, self.occ_model.feature_names_in_]
             occ_x_pred['predict'] = self.occ_model.predict(occ_x_pred)
-        if 0 in df[self.occupancy_col].unique():
+        if 0 in pred[self.occupancy_col].unique():
             unocc_x_pred = pred.loc[pred[self.occupancy_col] == 0,
                                     pred.columns != self.dependent_col]
             unocc_x_pred.drop(columns=self.occupancy_col, inplace=True)
@@ -369,6 +373,17 @@ class TOWTModel(Model):
                     self.tempi, args=(knot_temps[i], knot_temps[i-1])).values
 
         return pd.DataFrame(temp_var_dict), knot_temps
+    
+    def define_kts(self, n_chunks=6):
+        temp_array = np.copy(self.df[self.temperature_col].values)
+        temp_array = np.array_split(np.unique(np.sort(temp_array)), n_chunks)
+        kts = []
+        for i in range(len(temp_array)-1):
+            kt = (temp_array[i].max() + temp_array[i+1].min())/2
+            kts.append(kt)
+        
+        return(kts)
+        
 
     @staticmethod
     def define_tow_vars(df, time_interval):
@@ -408,4 +423,38 @@ class TOWTModel(Model):
         else:
             raise ValueError(
                 "Time interval supplied expected 'daily' or 'hourly'. "
-                "Neither of those were given.")
\ No newline at end of file
+                "Neither of those were given.")
+
+    @staticmethod
+    def get_tow(df, interval):
+        """
+
+
+        Parameters
+        ----------
+        df : TYPE
+            DESCRIPTION.
+        interval : TYPE
+            DESCRIPTION.
+
+        Returns
+        -------
+        None.
+
+        """
+        df = df.copy()
+        if interval.upper() == 'DAILY':
+            df['tow'] = df['time'].dt.dayofweek
+
+        elif interval.upper() == 'HOURLY':
+            dow = df['time'].dt.dayofweek
+            hour = df['time'].dt.hour
+            df['tow'] = dow*24 + hour
+
+        else:
+            raise ValueError(
+                "Time interval supplied expected 'daily' or 'hourly'. "
+                "Neither of those were given.")
+
+        df.drop(columns='time', inplace=True)
+        return(df)
